@@ -338,15 +338,21 @@ go_data_vector_val_load_values (GODataVector *vec)
 	vec->maximum = maximum;
 	vec->base.flags |= GO_DATA_CACHE_IS_VALID;
 }
+
 static double
 go_data_vector_val_get_value (GODataVector *vec, unsigned i)
 {
-	return vec->values[i];
+	GODataVectorVal const *val = (GODataVectorVal const *)vec;
+	g_return_val_if_fail (val != NULL && val->val != NULL && i < val->n, go_nan);
+	return val->val[i];
 }
+
 static char *
 go_data_vector_val_get_str (GODataVector *vec, unsigned i)
 {
-	return g_strdup_printf ("%g", vec->values[i]);
+	GODataVectorVal const *val = (GODataVectorVal const *)vec;
+	g_return_val_if_fail (val != NULL && val->val != NULL && i < val->n, NULL);
+	return g_strdup_printf ("%g", val->val[i]);
 }
 
 static char *
@@ -356,14 +362,16 @@ go_data_vector_val_as_str (GOData const *dat)
 	GString *str;
 	char sep, sz[G_ASCII_DTOSTR_BUF_SIZE];
 	unsigned i;
+
 	if (vec->n ==0)
 		return g_strdup ("");
-	sep = format_get_arg_sep ();
-	g_ascii_dtostr (sz, sizeof (sz), vec->val[0]);
+
+	sep = format_get_col_sep ();
+	g_snprintf (sz, sizeof (sz), "%g", vec->val[0]);
 	str = g_string_new (sz);
 	for (i = 1; i < vec->n; i++) {
 		g_string_append_c (str, sep);
-		g_ascii_dtostr (sz, sizeof (sz), vec->val[i]);
+		g_snprintf (sz, sizeof (sz), "%g", vec->val[i]);
 		g_string_append (str, sz);
 	}
 	return g_string_free (str, FALSE);
@@ -376,18 +384,27 @@ go_data_vector_val_from_str (GOData *dat, char const *str)
 	char sep, *end = (char*) str;
 	double val;
 	GArray *values;
+
 	g_return_val_if_fail (str != NULL, TRUE);
-	values = g_array_sized_new (FALSE, FALSE, sizeof(double), 16);
-	sep = format_get_arg_sep ();
+
 	if (vec->notify && vec->val)
 		(*vec->notify) (vec->val);
+
+	values = g_array_sized_new (FALSE, FALSE, sizeof(double), 16);
+	sep = 0;
 	vec->val = NULL;
 	vec->n = 0;
 	vec->notify = (GDestroyNotify) g_free;
 	while (1) {
-		val = g_ascii_strtod (end, &end);
+		val = g_strtod (end, &end);
 		g_array_append_val (values, val);
 		if (*end) {
+			if (!sep) {
+				/* allow the use of all possible seps */
+				if ((sep = format_get_arg_sep ()) != *end)
+					if ((sep = format_get_col_sep ()) != *end)
+						sep = format_get_row_sep ();
+			}
 			if (*end != sep) {
 				g_array_free (values, TRUE);
 				return FALSE;
@@ -403,6 +420,7 @@ go_data_vector_val_from_str (GOData *dat, char const *str)
 	vec->n = values->len;
 	vec->val = (double*) values->data;
 	g_array_free (values, FALSE);
+	go_data_emit_changed (GO_DATA (vec));
 	return TRUE;
 }
 
@@ -442,8 +460,8 @@ go_data_vector_val_new (double *val, unsigned n, GDestroyNotify notify)
 
 struct _GODataVectorStr {
 	GODataVector	 base;
-	char **str;
-	unsigned n;
+	char const * const *str;
+	int n;
 	GDestroyNotify notify;   
 
 	GOTranslateFunc translate_func;
@@ -469,11 +487,15 @@ go_data_vector_str_finalize (GObject *obj)
 {
 	GODataVectorStr *str = (GODataVectorStr *)obj;
 	if (str->notify && str->str != NULL)
-		(*str->notify) (str->str);
+		(*str->notify) ((gpointer)str->str);
 
 	if (str->translate_notify != NULL)
 		(*str->translate_notify) (str->translate_data);
 
+	if (str->base.values != NULL)
+		g_free (str->base.values);
+	str->base.values = NULL;
+
 	(*vector_str_parent_klass->finalize) (obj);
 }
 
@@ -484,11 +506,12 @@ go_data_vector_str_dup (GOData const *src)
 	GODataVectorStr const *src_val = (GODataVectorStr const *)src;
 	dst->n = src_val->n;
 	if (src_val->notify) {
-		unsigned i;
-		dst->str = g_new (char*, src_val->n + 1);
+		int i;
+		char const * *str = g_new (char const *, src_val->n + 1);
 		for (i = 0; i < src_val->n; i++)
-			dst->str[i] = g_strdup (src_val->str[i]);
-		dst->str[src_val->n] = NULL;
+			str[i] = g_strdup (src_val->str[i]);
+		str[src_val->n] = NULL;
+		dst->str = str;
 		dst->notify = cb_strings_destroy_notify;
 	} else
 		dst->str = src_val->str;
@@ -509,10 +532,12 @@ go_data_vector_str_as_str (GOData const *dat)
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
 	GString *str;
 	char sep;
-	unsigned i;
-	sep = format_get_arg_sep ();
+	int i;
+
+	sep = format_get_col_sep ();
 	if (vec->n ==0)
 		return g_strdup ("");
+
 	str = g_string_new ("");
 	g_string_append_c (str, '\"');
 	g_string_append (str, vec->str[0]);
@@ -532,12 +557,22 @@ go_data_vector_str_from_str (GOData *dat, char const *str)
 	GODataVectorStr *vec = GO_DATA_VECTOR_STR (dat);
 	char sep, *cur = (char*) str, *end, *val;
 	GArray *values;
+
 	g_return_val_if_fail (str != NULL, TRUE);
-	values = g_array_sized_new (FALSE, FALSE, sizeof(char*), 16);
-	/* A dirty workaround to know what should be the separator in the current locale */
-	sep = format_get_arg_sep ();
+
 	if (vec->notify && vec->str)
-		(*vec->notify) (vec->str);
+		(*vec->notify) ((gpointer)vec->str);
+
+	values = g_array_sized_new (FALSE, FALSE, sizeof(char*), 16);
+	/* search which separator has been used */
+	sep = format_get_col_sep ();
+	end = strchr (cur, sep);
+	if (end == NULL) {
+		sep = format_get_arg_sep ();
+		end = strchr (cur, sep);
+		if (end ==NULL)
+			sep = format_get_row_sep ();
+	}
 	vec->str = NULL;
 	vec->n = 0;
 	vec->notify = cb_strings_destroy_notify;
@@ -585,11 +620,12 @@ go_data_vector_str_from_str (GOData *dat, char const *str)
 		g_array_free (values, TRUE);
 		return TRUE;
 	}
+	vec->n = values->len;
 	val = NULL;
 	g_array_append_val (values, val);
-	vec->n = values->len;
-	vec->str = (char**) values->data;
+	vec->str = (char const*const*) values->data;
 	g_array_free (values, FALSE);
+	go_data_emit_changed (GO_DATA (vec));
 	return TRUE;
 }
 
@@ -597,17 +633,48 @@ static void
 go_data_vector_str_load_len (GODataVector *vec)
 {
 	vec->base.flags |= GO_DATA_VECTOR_LEN_CACHED;
+	if (vec->values && vec->len != ((GODataVectorStr *)vec)->n) {
+		g_free (vec->values);
+		vec->values = NULL;
+	}
 	vec->len = ((GODataVectorStr *)vec)->n;
 }
+
 static void
 go_data_vector_str_load_values (GODataVector *vec)
 {
+	char *end;
+	GODataVectorStr const *strs = (GODataVectorStr const *)vec;
+	double minimum = DBL_MAX, maximum = -DBL_MAX;
+	int i = strs->n;
+
+	if (vec->values == NULL)
+		vec->values = g_new (double, vec->len);
+	while (i-- > 0) {
+		vec->values[i] = g_strtod (strs->str[i], &end);
+		if (*end) {
+			vec->values[i] = go_nan;
+			continue;
+		}
+		if (minimum > vec->values[i])
+			minimum = vec->values[i];
+		if (maximum < vec->values[i])
+			maximum = vec->values[i];
+	}
+	vec->minimum = minimum;
+	vec->maximum = maximum;
+	vec->base.flags |= GO_DATA_CACHE_IS_VALID;
 }
+
 static double
 go_data_vector_str_get_value (GODataVector *vec, unsigned i)
 {
-	return go_nan;
+	char *end;
+	GODataVectorStr *strs = (GODataVectorStr *)vec;
+	double d = g_strtod (strs->str[i], &end);
+	return (*end)? go_nan: d;
 }
+
 static char *
 go_data_vector_str_get_str (GODataVector *vec, unsigned i)
 {
@@ -653,7 +720,7 @@ GSF_CLASS (GODataVectorStr, go_data_vector_str,
 	   GO_DATA_VECTOR_TYPE)
 
 GOData *
-go_data_vector_str_new (char **str, unsigned n, GDestroyNotify   notify)
+go_data_vector_str_new (char const * const *str, unsigned n, GDestroyNotify notify)
 {
 	GODataVectorStr *res = g_object_new (GO_DATA_VECTOR_STR_TYPE, NULL);
 	res->str = str;
@@ -812,26 +879,28 @@ go_data_matrix_val_as_str (GOData const *dat)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
 	GString *str;
-	char sep, col_sep, sz[G_ASCII_DTOSTR_BUF_SIZE];
+	char row_sep, col_sep, sz[G_ASCII_DTOSTR_BUF_SIZE];
 	int i, j;
+
 	if (mat->size.rows == 0 || mat->size.columns == 0)
 		return g_strdup ("");
-	sep = format_get_arg_sep ();
+
 	col_sep = format_get_col_sep ();
-	g_ascii_dtostr (sz, sizeof (sz), mat->val[0]);
+	row_sep = format_get_row_sep ();
+	g_snprintf (sz, sizeof (sz), "%g", mat->val[0]);
 	str = g_string_new (sz);
 	for (j = 1; j < mat->size.columns; j++) {
 		g_string_append_c (str, col_sep);
-		g_ascii_dtostr (sz, sizeof (sz), mat->val[j]);
+		g_snprintf (sz, sizeof (sz), "%g", mat->val[j]);
 		g_string_append (str, sz);
 	}
 	for (i = 1; i < mat->size.rows; i++) {
-		g_string_append_c (str, sep);
-		g_ascii_dtostr (sz, sizeof (sz), mat->val[i * mat->size.columns]);
+		g_string_append_c (str, row_sep);
+		g_snprintf (sz, sizeof (sz), "%g", mat->val[i * mat->size.columns]);
 		g_string_append (str, sz);
 		for (j = 1; j < mat->size.columns; j++) {
 			g_string_append_c (str, col_sep);
-			g_ascii_dtostr (sz, sizeof (sz), mat->val[i * mat->size.columns + j]);
+			g_snprintf (sz, sizeof (sz), "%g", mat->val[i * mat->size.columns + j]);
 			g_string_append (str, sz);
 		}
 	}
@@ -842,14 +911,16 @@ static gboolean
 go_data_matrix_val_from_str (GOData *dat, char const *str)
 {
 	GODataMatrixVal *mat = GO_DATA_MATRIX_VAL (dat);
-	char sep, col_sep, *end = (char*) str;
+	char row_sep, col_sep, *end = (char*) str;
 	int i, j, columns;
 	double val;
 	GArray *values;
+
 	g_return_val_if_fail (str != NULL, TRUE);
+
 	values = g_array_sized_new (FALSE, FALSE, sizeof(double), 16);
-	sep = format_get_arg_sep ();
 	col_sep = format_get_col_sep ();
+	row_sep = format_get_row_sep ();
 	i = j = columns = 0;
 	if (mat->notify && mat->val)
 		(*mat->notify) (mat->val);
@@ -858,12 +929,12 @@ go_data_matrix_val_from_str (GOData *dat, char const *str)
 	mat->size.columns = 0;
 	mat->notify = g_free;
 	while (1) {
-		val = g_ascii_strtod (end, &end);
+		val = g_strtod (end, &end);
 		g_array_append_val (values, val);
 		if (*end) {
 			if (*end == col_sep)
 				j++;
-			else if (*end == sep) {
+			else if (*end == row_sep) {
 				if (columns > 0) {
 					if (j == columns - 1) {
 						i++;
@@ -897,6 +968,7 @@ go_data_matrix_val_from_str (GOData *dat, char const *str)
 	mat->size.rows = i + 1;
 	mat->val = (double*) values->data;
 	g_array_free (values, FALSE);
+	go_data_emit_changed (GO_DATA (mat));
 	return TRUE;
 }
 
