@@ -152,9 +152,7 @@ map_discrete_init (GogAxisMap *map, double offset, double length)
 	data = map->data;
 
 	if (gog_axis_get_bounds (map->axis, &data->min, &data->max)) {
-		data->scale = (map->axis->center_on_ticks)?
-				1.0 / (data->max - data->min - 1):
-				1.0 / (data->max - data->min);
+		data->scale = 1.0 / (data->max - data->min);
 		data->a = data->scale * length;
 		data->b = offset - data->a * data->min;
 		return TRUE;
@@ -181,9 +179,7 @@ map_discrete_to_view (GogAxisMap *map, double value)
 	MapData *data = map->data;
 
 	return map->axis->inverted ? 
-		((map->axis->center_on_ticks)?
-			(data->min + data->max - 1 - value) * data->a + data->b :
-			(data->min + data->max - value) * data->a + data->b) :
+		(data->min + data->max - value) * data->a + data->b :
 		value * data->a + data->b;
 }
 
@@ -193,9 +189,7 @@ map_discrete_from_view (GogAxisMap *map, double value)
 	MapData *data = map->data;
 
 	return map->axis->inverted ? 
-		((map->axis->center_on_ticks)?
-			data->min + data->max -1 - (value - data->b) / data->a :
-			data->min + data->max - (value - data->b) / data->a) :
+		data->min + data->max - (value - data->b) / data->a :
 		(value - data->b) / data->a;
 }
 
@@ -242,8 +236,6 @@ map_discrete_calc_ticks (GogAxis *axis)
 	}
 		
 	tick_nbr = rint (maximum -minimum) + 1;
-	if (axis->center_on_ticks)
-		tick_nbr--;
 	if (tick_nbr < 1 || tick_nbr > GOG_AXIS_MAX_TICK_NBR) {
 		gog_axis_set_ticks (axis, 0, NULL);
 		return;
@@ -253,16 +245,12 @@ map_discrete_calc_ticks (GogAxis *axis)
 	for (i = 0; i < tick_nbr; i++) {
 		ticks[i].position = (double) (i);
 
-		/* Minimum >= .0 test is a trick to know if it's a barcol or an area/line plot */
-		if (i == 0 && minimum >=.0 && !axis->center_on_ticks)
-			ticks[i].type = GOG_AXIS_TICK_NONE;
-		else
-			ticks[i].type = i % major_tick == 0 ?
-				GOG_AXIS_TICK_MAJOR :
-				GOG_AXIS_TICK_MINOR;
+		ticks[i].type = i % major_tick == 0 ?
+			GOG_AXIS_TICK_MAJOR :
+			GOG_AXIS_TICK_MINOR;
 
 		if ((i % major_label == 0) && 
-		    (i < tick_nbr - 1 || minimum >= .0)) {
+		    (i < tick_nbr - 1 || axis->center_on_ticks)) {
 			if (axis->labels != NULL) {
 				if (i < go_data_vector_get_len (axis->labels))
 					ticks[i].label = go_data_vector_get_str (axis->labels, i);
@@ -1108,6 +1096,14 @@ gog_axis_set_property (GObject *obj, guint param_id,
 		if (axis->type != itmp) {
 			axis->type = itmp;
 			resized = TRUE;
+			if (axis->type == GOG_AXIS_PSEUDO_3D)
+				g_object_set (obj,
+						"major-tick-labeled", FALSE,
+						"major-tick-in", FALSE,
+						"major-tick-out", FALSE,
+						"minor-tick-in", FALSE,
+						"minor-tick-out", FALSE,
+						NULL);
 		}
 		break;
 	case AXIS_PROP_INVERT:
