@@ -24,6 +24,8 @@
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/data/go-data.h>
+#include <goffice/data/go-data-simple.h>
+#include <goffice/utils/go-math.h>
 
 GType
 gog_dataset_get_type (void)
@@ -206,3 +208,54 @@ gog_dataset_parent_changed (GogDataset *set, gboolean was_set)
 	if (was_set)
 		gog_object_request_update (GOG_OBJECT (set));
 }
+
+void
+gog_dataset_dup_to_simple (GogDataset const *src, GogDataset *dst)
+{
+	gint	     n, last;
+	GOData *src_dat, *dst_dat;
+	gog_dataset_dims (src, &n, &last);
+	for ( ; n <= last ; n++) {
+		src_dat = gog_dataset_get_dim (src, n);
+		if (src_dat == NULL)
+			continue;
+		dst_dat = NULL;
+		/* for scalar and vector data, try to transform to values first
+		if we find go_nan, use strings */
+		if (IS_GO_DATA_SCALAR (src_dat)) {
+			double d =  go_data_scalar_get_value (GO_DATA_SCALAR (src_dat));
+			dst_dat =(d != go_nan)? go_data_scalar_val_new (d):
+						go_data_scalar_str_new (
+							g_strdup (go_data_scalar_get_str (GO_DATA_SCALAR (src_dat))),
+							TRUE);
+		} else if (IS_GO_DATA_VECTOR (src_dat)) {
+			gboolean as_values = TRUE;
+			GODataVector *vec = GO_DATA_VECTOR (src_dat);
+			double *d = go_data_vector_get_values (vec);
+			int i, n = go_data_vector_get_len (vec);
+			for (i = 0; i < n; i++)
+				if (d[i] == go_nan) {
+					as_values = FALSE;
+					break;
+				}
+			if (as_values)
+				/* we don't need to duplicate, since this is used only for
+				short lived objects */
+				dst_dat = go_data_vector_val_new (d, n, NULL);
+			else {
+				char **str = g_new (char*, n + 1);
+				str[n] = NULL;
+				for (i = 0; i < n; i++)
+					str[i] = go_data_vector_get_str (vec, i);
+				dst_dat = go_data_vector_str_new ((char const* const*) str, n, g_free);
+			}
+		} else if (IS_GO_DATA_MATRIX (src_dat)) {
+			/* only values are supported so don't care */
+			GODataMatrix *mat = GO_DATA_MATRIX (src_dat);
+			GODataMatrixSize size = go_data_matrix_get_size (mat);
+			dst_dat = go_data_matrix_val_new (go_data_matrix_get_values (mat),
+									size.rows, size.columns, NULL);
+		}
+		gog_dataset_set_dim (dst, n, dst_dat, NULL);
+	}
+}
