@@ -29,6 +29,7 @@
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-plot.h>
+#include <goffice/graph/gog-reg-curve.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-plot-engine.h>
 #include <goffice/graph/gog-data-allocator.h>
@@ -127,6 +128,8 @@ struct _GraphGuruTypeSelector {
 	GogPlotType	*current_type;
 	FooCanvasGroup const *current_family_item;
 	FooCanvasItem const  *current_minor_item;
+
+	int max_priority_so_far;
 };
 
 enum {
@@ -146,6 +149,7 @@ enum {
 #define BORDER	5
 
 #define PLOT_TYPE_KEY		"plot_type"
+#define REG_CURVE_TYPE_KEY	"reg_curve_type"
 #define FIRST_MINOR_TYPE	"first_minor_type"
 #define ROLE_KEY		"role"
 #define STATE_KEY		"plot_type"
@@ -471,6 +475,12 @@ cb_plot_families_init (char const *id, GogPlotFamily *family,
 		PLOT_FAMILY_TYPE_CANVAS_GROUP,	group,
 		-1);
 
+	if (typesel->max_priority_so_far < family->priority) {
+		typesel->max_priority_so_far = family->priority;
+		gtk_tree_selection_select_iter (
+			gtk_tree_view_get_selection (typesel->list_view), &iter);
+	}
+
 	closure.typesel = typesel;
 	closure.group	= group;
 	closure.current_type = NULL;
@@ -678,6 +688,47 @@ plot_type_menu_create (GraphGuruState *s)
 	return NULL;
 }
 
+static void
+cb_graph_guru_add_reg_curve (GtkWidget *w, GraphGuruState *s)
+{
+	GogRegCurveType *type = g_object_get_data (G_OBJECT (w), REG_CURVE_TYPE_KEY);
+	GogRegCurve *curve = gog_reg_curve_new_by_type (type);
+	gog_object_add_by_name (GOG_OBJECT (s->prop_object),
+		"Regression curve", GOG_OBJECT (curve));
+}
+
+static void
+cb_reg_curve_type_menu_create (char const *id, GogRegCurveType *type,
+			    struct type_menu_create *closure)
+{
+	GtkWidget *menu;
+
+	menu = gtk_menu_item_new_with_label (_(type->name));
+	g_object_set_data (G_OBJECT (menu), REG_CURVE_TYPE_KEY, type);
+	g_signal_connect (G_OBJECT (menu),
+		"activate",
+		G_CALLBACK (cb_graph_guru_add_reg_curve), closure->state);
+	gtk_menu_shell_append (GTK_MENU_SHELL (closure->menu), menu);
+	closure->non_blank = TRUE;
+}
+
+static GtkWidget *
+reg_curve_type_menu_create (GraphGuruState *s)
+{
+	struct type_menu_create closure;
+	closure.state = s;
+	closure.menu = gtk_menu_new ();
+	closure.non_blank = FALSE;
+
+	g_hash_table_foreach ((GHashTable *)gog_reg_curve_types (),
+		(GHFunc) cb_reg_curve_type_menu_create, &closure);
+
+	if (closure.non_blank)
+		return closure.menu;
+	gtk_object_destroy (GTK_OBJECT (closure.menu));
+	return NULL;
+}
+
 static void
 cb_attr_tree_selection_change (GraphGuruState *s)
 {
@@ -723,7 +774,14 @@ cb_attr_tree_selection_change (GraphGuruState *s)
 				role = ptr->data;
 				/* somewhat hackish, but I do not see a need
 				 * for anything more general yet */
-				if (strcmp (role->id, "Plot")) {
+				if (!strcmp (role->id, "Regression curve")) {
+					GtkWidget *submenu = reg_curve_type_menu_create (s);
+					if (submenu != NULL) {
+						tmp = gtk_menu_item_new_with_label (_(role->id));
+						gtk_menu_item_set_submenu (GTK_MENU_ITEM (tmp), submenu);
+					} else 
+						continue;
+				} else if (strcmp (role->id, "Plot")) {
 					tmp = gtk_menu_item_new_with_label (_(role->id));
 					g_object_set_data (G_OBJECT (tmp), ROLE_KEY,
 						(gpointer)role);
@@ -1212,6 +1270,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	typesel->current_minor_item = NULL;
 	typesel->current_type = NULL;
 	typesel->sample_graph_item = NULL;
+	typesel->max_priority_so_far = -1;
 
 	selector = glade_xml_get_widget (gui, "type_selector");
 
@@ -1220,6 +1279,9 @@ graph_guru_type_selector_new (GraphGuruState *s)
 					     GDK_TYPE_PIXBUF,
 					     G_TYPE_STRING,
 					     G_TYPE_POINTER);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (typesel->model),
+		PLOT_FAMILY_TYPE_NAME, GTK_SORT_ASCENDING);
+
 	typesel->list_view = GTK_TREE_VIEW (glade_xml_get_widget (gui, "type_treeview"));
 	gtk_tree_view_set_model (typesel->list_view, GTK_TREE_MODEL (typesel->model));
 	gtk_tree_view_append_column (typesel->list_view,
@@ -1232,11 +1294,7 @@ graph_guru_type_selector_new (GraphGuruState *s)
 			gtk_cell_renderer_text_new (),
 			"text", PLOT_FAMILY_TYPE_NAME,
 			NULL));
-	selection = gtk_tree_view_get_selection (typesel->list_view);
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-	g_signal_connect_swapped (selection,
-		"changed",
-		G_CALLBACK (cb_selection_changed), typesel);
+
 
 	/* Setup an canvas to display the sample image & the sample plot. */
 	typesel->canvas = foo_canvas_new ();
@@ -1265,6 +1323,12 @@ graph_guru_type_selector_new (GraphGuruState *s)
 	g_hash_table_foreach ((GHashTable *)gog_plot_families (),
 		(GHFunc) cb_plot_families_init, typesel);
 
+	selection = gtk_tree_view_get_selection (typesel->list_view);
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
+	g_signal_connect_swapped (selection,
+		"changed",
+		G_CALLBACK (cb_selection_changed), typesel);
+
 	/* The alpha blended selection box */
 	typesel->selector = foo_canvas_item_new (
 		foo_canvas_root (FOO_CANVAS (typesel->canvas)),
