@@ -58,7 +58,7 @@
 #endif
 
 /* g_access would be nice here.  */
-static gboolean
+static int
 go_access (const char *filename, int what)
 {
 #ifdef G_OS_WIN32
@@ -355,12 +355,11 @@ go_gtk_file_sel_dialog (GtkWindow *toplevel, GtkWidget *w)
 	gboolean result = FALSE;
 	gulong delete_handler;
 
+	g_return_val_if_fail (GTK_IS_WINDOW (toplevel), FALSE);
 	g_return_val_if_fail (GTK_IS_FILE_CHOOSER (w), FALSE);
 
 	gtk_window_set_modal (GTK_WINDOW (w), TRUE);
-	/* Note: toplevel will be NULL if called (indirectly) from gog-style.c  */
-	if (NULL != toplevel)
-		go_gtk_window_set_transient (toplevel, GTK_WINDOW (w));
+	go_gtk_window_set_transient (toplevel, GTK_WINDOW (w));
 	g_signal_connect (w, "response",
 		G_CALLBACK (fsel_response_cb), &result);
 	delete_handler = g_signal_connect (w, "delete_event",
@@ -442,9 +441,10 @@ update_preview_cb (GtkFileChooser *chooser)
 		if (buf) {
 			dummy = FALSE;
 		} else {
-			buf = gtk_icon_theme_load_icon (
-				gtk_icon_theme_get_default (),
-				"unknown_image", 100, 100, NULL);
+			GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (chooser));
+			buf = gtk_icon_theme_load_icon
+				(gtk_icon_theme_get_for_screen (screen),
+				 "unknown_image", 100, 100, NULL);
 			dummy = buf != NULL;
 		}
 
@@ -533,7 +533,11 @@ go_gtk_select_image (GtkWindow *toplevel, const char *initial)
 {
 	const char *key = "go_gtk_select_image";
 	char *uri = NULL;
-	GtkFileChooser *fsel = gui_image_chooser_new (FALSE);
+	GtkFileChooser *fsel;
+
+	g_return_val_if_fail (GTK_IS_WINDOW (toplevel), NULL);
+
+	fsel = gui_image_chooser_new (FALSE);
 
 	if (!initial)
 		initial = g_object_get_data (G_OBJECT (toplevel), key);
@@ -727,7 +731,7 @@ typedef struct {
 #ifdef WITH_GNOME
 #include <libgnome/gnome-help.h>
 #elif defined(G_OS_WIN32)
-#include "htmlhelp-stub.h"
+#include <goffice/utils/win32-stub.h>
 #endif
 static void
 go_help_display (CBHelpPaths const *paths)
